#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 MemoTrie
version:              0.6.11
visibility:           public
id:                   MemoTrie-0.6.11-IV7L5bgacYvGto1GmVySKD
key:                  MemoTrie-0.6.11-IV7L5bgacYvGto1GmVySKD
license:              BSD-3-Clause
copyright:            (c) 2008-2019 by Conal Elliott
maintainer:           conal@conal.net
author:               Conal Elliott 
stability:            experimental
homepage:             https://github.com/conal/MemoTrie
synopsis:             Trie-based memo functions
description:
    MemoTrie provides a basis for memoized functions over some domains,
    using tries.  It'\''s based on ideas from Ralf Hinze and code from
    Spencer Janssen. Generic support thanks to Sam Boosalis.

    Project wiki page: <http://haskell.org/haskellwiki/MemoTrie>

    &#199; 2008-2019 by Conal Elliott; BSD3 license.

category:             Data
abi:                  3d918f304590effd06f7f19411e69e2f
exposed:              True
exposed-modules:      Data.MemoTrie
import-dirs:          /usr/lib/ghc-9.6.6/site-local/MemoTrie-0.6.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/MemoTrie-0.6.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/MemoTrie-0.6.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-memotrie
hs-libraries:         HSMemoTrie-0.6.11-IV7L5bgacYvGto1GmVySKD
depends:
    base-4.18.2.1 newtype-generics-0.6.3-EKYQK91M5lC8oM68PPfaTA

haddock-interfaces:   /usr/share/doc/haskell-memotrie/html/MemoTrie.haddock
haddock-html:         /usr/share/doc/haskell-memotrie/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

